diff --git a/osu.Game/Rulesets/Difficulty/DifficultyCalculator.cs b/osu.Game/Rulesets/Difficulty/DifficultyCalculator.cs
index c6e54c52e7..29ec9aae25 100644
--- a/osu.Game/Rulesets/Difficulty/DifficultyCalculator.cs
+++ b/osu.Game/Rulesets/Difficulty/DifficultyCalculator.cs
@@ -25,7 +25,7 @@ namespace osu.Game.Rulesets.Difficulty
protected override DifficultyAttributes Calculate(IBeatmap beatmap, Mod[] mods, double clockRate)
{
- var skills = CreateSkills();
+ var skills = CreateSkills(beatmap);
if (!beatmap.HitObjects.Any())
return CreateDifficultyAttributes(beatmap, mods, skills, clockRate);
@@ -106,9 +106,9 @@ namespace osu.Game.Rulesets.Difficulty
///
/// Creates to describe beatmap's calculated difficulty.
///
/// The whose difficulty was processed.
/// The s that were applied during the process.
/// The skills which processed the difficulty.
/// The rate at which the gameplay clock is run at.
protected abstract DifficultyAttributes CreateDifficultyAttributes(IBeatmap beatmap, Mod[] mods, Skill[] skills, double clockRate);
@@ -121,9 +121,10 @@ namespace osu.Game.Rulesets.Difficulty
protected abstract IEnumerable CreateDifficultyHitObjects(IBeatmap beatmap, double clockRate);
///
- /// Creates the s to calculate the difficulty of s.
+ /// Creates the s to calculate the difficulty of an .
///
+ /// The whose difficulty will be calculated.The s.
- protected abstract Skill[] CreateSkills();
+ protected abstract Skill[] CreateSkills(IBeatmap beatmap);
}
}
@@ -106,9 +106,9 @@ namespace osu.Game.Rulesets.Difficulty
/// Creates to describe beatmap's calculated difficulty.
///
- /// The whose difficulty was processed.
- /// The s that were applied during the process.
- /// The skills which processed the difficulty.
+ /// The whose difficulty was calculated.
+ /// The s that difficulty was calculated with.
+ /// The skills which processed the beatmap.
/// The rate at which the gameplay clock is run at.
protected abstract DifficultyAttributes CreateDifficultyAttributes(IBeatmap beatmap, Mod[] mods, Skill[] skills, double clockRate);